@@ -7,7 +7,7 @@
 //! [tokio](https://tokio.rs) or [async-std](https://async.rs)
 use std::sync::Arc;
 use parking_lot::RwLock;
-use tokio_stream::Stream;
+use futures::stream::Stream;
 use crate::world::World;
 
 /// System core trait
@@ -15,3 +15,4 @@ pub trait System : Stream {
     /// Get the [world](crate::world::World) of System
     fn world(&self) -> Arc<RwLock<World>>;
 }
+
